OC.L10N.register(
    "settings",
    {
    "Private" : "Yksityinen",
    "Local" : "Paikallinen",
    "Only visible to people on this instance and guests" : "Vain näkyvissä tämän instanssin ihmisille ja vieraille",
    "Federated" : "Federoitu",
    "Only synchronize to trusted servers" : "Synkronoi vain luotetulle palvelimelle",
    "Published" : "Julkaistu",
    "Verify" : "Vahvista",
    "Verifying …" : "Vahvistetaan…",
    "Unable to change password" : "Salasanan vaihto ei onnistunut",
    "Very weak password" : "Erittäin heikko salasana",
    "Weak password" : "Heikko salasana",
    "So-so password" : "Kohtalainen salasana",
    "Good password" : "Hyvä salasana",
    "Strong password" : "Vahva salasana",
    "An error occurred while changing your language. Please reload the page and try again." : "Kieltä vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Maa-asetustoa vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
    "Week starts on {fdow}" : "Viikon ensimmäinen päivä on {fdow}",
    "Groups" : "Ryhmät",
    "Group list is empty" : "Ryhmälista on tyhjä",
    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
    "{actor} added you to group {group}" : "{actor} lisäsi sinut ryhmään {group}",
    "You added {user} to group {group}" : "Lisäsit käyttäjän {user} ryhmään {group}",
    "{actor} added {user} to group {group}" : "{actor} lisäsi käyttäjän {user} ryhmään {group}",
    "An administrator added you to group {group}" : "Ylläpitäjä lisäsi sinut ryhmään {group}",
    "An administrator added {user} to group {group}" : "Ylläpitäjä lisäsi käyttäjän {user} ryhmään {group}",
    "{actor} removed you from group {group}" : "{actor} poisti sinut ryhmästä {group}",
    "You removed {user} from group {group}" : "Poistit käyttäjän {user} ryhmästä {group}",
    "{actor} removed {user} from group {group}" : "{actor} poisti käyttäjän {user} ryhmästä {group}",
    "An administrator removed you from group {group}" : "Ylläpitäjä poisti sinut ryhmästä {group}",
    "An administrator removed {user} from group {group}" : "Ylläpitäjä poisti käyttäjän {user} ryhmästä {group}",
    "Your <strong>group memberships</strong> were modified" : "Sinun <strong>ryhmäjäsenyyksiä</strong> muokattiin",
    "{actor} changed your password" : "{actor} muutti salasanasi",
    "You changed your password" : "Muutit salasanasi",
    "Your password was reset by an administrator" : "Ylläpitäjä nollasi salasanasi",
    "Your password was reset" : "Salasanasi nollattiin",
    "{actor} changed your email address" : "{actor} muutti sähköpostiosoitteesi",
    "You changed your email address" : "Muutit sähköpostiosoitteesi",
    "Your email address was changed by an administrator" : "Ylläpitäjä muutti sähköpostiosoitteesi",
    "You created app password \"{token}\"" : "Loit sovellussalasanan \"{token}\"",
    "An administrator created app password \"{token}\"" : "Ylläpitäjä loi sovellussalasanan \"{token}\"",
    "You deleted app password \"{token}\"" : "Poistit sovellussalasanan \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Nimesit sovellussalasanan \"{token}\" uudelleen muotoon \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Annoit pääsyn tiedostojärjestelmään sovellussalasanalle \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Kumosit pääsyn tiedostojärjestelmään sovellussalasanalta \"{token}\"",
    "Security" : "Turvallisuus",
    "You successfully logged in using two-factor authentication (%1$s)" : "Kirjauduit onnistuneesti sisään kaksivaiheista tunnistautumista käyttäen (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Kirjautumisyritys kaksivaiheista tunnistautumista käyttäen epäonnistui (%1$s)",
    "Remote wipe was started on %1$s" : "Etätyhjennys aloitettiin %1$s",
    "Remote wipe has finished on %1$s" : "Etätyhjennys valmistui %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Salasanaasi</strong> tai <strong>sähköpostiosoitettasi</strong> muokattiin",
    "Could not remove app." : "Sovellusta ei voitu poistaa.",
    "Could not update app." : "Sovellusta ei voitu päivittää.",
    "Wrong password" : "Väärä salasana",
    "Unable to change personal password" : "Henkilökohtaista salasanaa ei voitu vaihtaa",
    "Saved" : "Tallennettu",
    "No user supplied" : "Käyttäjää ei määritetty",
    "Unable to change password. Password too long." : "Salasanaa ei voitu vaihtaa. Salasana on liian pitkä.",
    "Authentication error" : "Tunnistautumisvirhe",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Anna ylläpitäjän palautussalasana; muuten kaikki käyttäjien data menetetään.",
    "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL käyttää vanhentunutta %1$s versiota (%2$s). Päivitä käyttöjärjestelmäsi tai toiminnot, kuten %3$s, eivät toimi luotettavasti.",
    "Invalid SMTP password." : "Virheellinen SMTP-salasana.",
    "Email setting test" : "Sähköpostiasetusten testaus",
    "Well done, %s!" : "Hyvin tehty, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jos vastaanotit tämän viestin, sähköpostimääritykset vaikuttavat olevan kunnossa.",
    "Email could not be sent. Check your mail server log" : "Sähköpostia ei voitu lähettää. Tarkista sähköpostipalvelimen lokitiedosto",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Sähköpostia lähettäessä tapahtui virhe. Tarkista asetukset. (Virhe: %s)",
    "Invalid user" : "Virheellinen käyttäjä",
    "Invalid mail address" : "Virheellinen sähköpostiosoite",
    "Settings saved" : "Asetukset tallennettu",
    "Unable to change full name" : "Koko nimen muuttaminen epäonnistui",
    "Unable to change email address" : "Sähköpostiosoitteen vaihtaminen ei onnistunut",
    "Unable to set invalid phone number" : "Virheellisen puhelinnumeron asettaminen ei onnistu",
    "Unable to set invalid website" : "Virheellisen verkkosivun asettaminen ei onnistu",
    "Some account data was invalid" : "Jokin tilidata oli virheellistä",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Jotta Twitter-tilisi on mahdollista vahvistaa, twiittaa seuraava viesti (varmista että lähetät viestin sellaisenaan ilman rivivaihtoja):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Jotta verkkosivustosi on mahdollista vahvistaa, aseta seuraava sisältö verkkosivustosi juureen '.well-known/CloudIdVerificationCode.txt' (varmista että koko teksti on yhdellä rivillä):",
    "Your password on %s was changed." : "Salasanasi osoitteessa %s on muutettu.",
    "Your password on %s was reset by an administrator." : "Ylläpitäjä muutti salasanasi osoitteessa %s.",
    "Your password on %s was reset." : "%s-salasanasi on nollattu.",
    "Password for %1$s changed on %2$s" : "Salasana käyttäjälle %1$s muutettu osoitteessa %2$s",
    "Password changed for %s" : "Salasana muutettu käyttäjälle %s",
    "If you did not request this, please contact an administrator." : "Jos et pyytänyt tätä, ota yhteyttä ylläpitäjään.",
    "Your email address on %s was changed." : "Sähköpostiosoitteesi osoitteessa %s on muutettu.",
    "Your email address on %s was changed by an administrator." : "Ylläpitäjä muutti sähköpostiosoitteesi osoitteessa %s.",
    "Email address for %1$s changed on %2$s" : "Sähköpostiosoite käyttäjälle %1$s muutettu osoitteessa %2$s",
    "Email address changed for %s" : "Sähköpostiosoite muutettu käyttäjälle %s",
    "The new email address is %s" : "Uusi sähköpostiosoite on %s",
    "Your %s account was created" : "%s-tilisi luotiin",
    "Welcome aboard" : "Tervetuloa mukaan",
    "Welcome aboard %s" : "Tervetuloa mukaan %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Tervetuloa %s-tilillesi. Voit lisätä, suojata ja jakaa tietojasi.",
    "Your username is: %s" : "Käyttäjätunnuksesi on: %s",
    "Set your password" : "Aseta salasanasi",
    "Go to %s" : "Siirry %s-palveluun",
    "Install Client" : "Asenna sovellus",
    "Apps" : "Sovellukset",
    "Settings" : "Asetukset",
    "Personal" : "Henkilökohtainen",
    "Administration" : "Ylläpito",
    "Additional settings" : "Lisäasetukset",
    "Administration privileges" : "Ylläpitäjän oikeudet",
    "Groupware" : "Groupware",
    "Overview" : "Yleiskuvaus",
    "Basic settings" : "Perusasetukset",
    "Sharing" : "Jakaminen",
    "Personal info" : "Henkilökohtaiset tiedot",
    "Mobile & desktop" : "Mobiili ja työpöytä",
    "Email server" : "Sähköpostipalvelin",
    "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
    "Background jobs" : "Taustatyöt",
    "Create" : "Luo",
    "Change" : "Muuta",
    "Delete" : "Poista",
    "Reshare" : "Jaa edelleen",
    "Unlimited" : "Rajoittamaton",
    "Verifying" : "Vahvistetaan",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Vanha palvelinpuolen salausmenetelmä on käytössä. Suosittelemme sen ottamista pois käytöstä.",
    "Profile information" : "Profiilitiedot",
    "Nextcloud settings" : "Nextcloud-asetukset",
    "Here you can decide which group can access certain sections of the administration settings." : "Tässä voit päättää, mitkä ryhmät voivat käyttää tiettyja osioita ylläpitäjän asetuksista.",
    "None" : "Ei mitään",
    "Unable to modify setting" : "Asetuksen muokkaaminen ei onnistu",
    "Two-Factor Authentication" : "Kaksivaiheinen tunnistautuminen",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Kaksivaiheinen tunnistautuminen voidaan pakottaa kaikille käyttäjille ja halutuille ryhmille. Mikäli heillä ei ole kaksivaiheista tunnistautumistapaa määriteltynä, he eivät pysty kirjautumaan järjestelmään.",
    "Enforce two-factor authentication" : "Pakota kaksivaiheinen tunnistautuminen",
    "Limit to groups" : "Rajoita ryhmiin",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Kaksivaiheisen tunnistautumisen pakottaminen on mahdollista kohdentaa vain tietyille ryhmille.",
    "Two-factor authentication is enforced for all members of the following groups." : "Kaksivaiheisen tunnistautuminen on pakotettu kaikille seuraavien ryhmien jäsenille.",
    "Enforced groups" : "Pakotetut ryhmät",
    "Two-factor authentication is not enforced for members of the following groups." : "Kaksivaiheisen tunnistautuminen ei ole pakotettu seuraavien ryhmien jäsenille.",
    "Excluded groups" : "Poissuljetut ryhmät",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Kun ryhmiä on valittu tai poissuljettu, ne käyttävät seuraavaa logiikkaa määrittääkseen käyttäjän kaksivaiheisen tunnistautumisen (2FA) pakottamisen: Jos ryhmiä ei ole valittu, 2FA on käytössä kaikilla paitsi poissuljetuilla ryhmillä. Jos ryhmiä on valittu, 2FA on käytössä kaikilla niiden jäsenillä. Jos käyttäjä on sekä valitussa että poissuljetussa ryhmässä, valittu ryhmä on etusijalla ja 2FA on käytössä.",
    "Save changes" : "Tallenna muutokset",
    "All" : "Kaikki",
    "Limit app usage to groups" : "Rajoita sovelluskäyttö ryhmiin",
    "No results" : "Ei tuloksia",
    "Update to {version}" : "Päivitä versioon {version}",
    "Remove" : "Poista",
    "Disable" : "Poista käytöstä",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt minimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt maksimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tätä sovellusta ei voi asentaa, koska seuraavat riippuvuudet eivät täyty:",
    "View in store" : "Näytä kaupassa",
    "Visit website" : "Käy verkkosivustolla",
    "Report a bug" : "Ilmoita viasta",
    "User documentation" : "Käyttäjädokumentaatio",
    "Admin documentation" : "Ylläpitäjän ohjeistus",
    "Developer documentation" : "Kehittäjädokumentaatio",
    "This app is supported via your current Nextcloud subscription." : "Tämä sovellus on tuettu nykyisen Nextcloud-tilauksesi kautta.",
    "Supported" : "Tuettu",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Esitellyt sovellukset on yhteisön itsensä kehitettämiä. Ne tarjoavat keskeisiä toimintoja ja ovat valmiita tuotantokäyttöön.",
    "Featured" : "Poiminta",
    "Update to {update}" : "Päivitä versioon {update}",
    "All apps are up-to-date." : "Kaikki sovellukset ovat ajan tasalla.",
    "Results from other categories" : "Tulokset muista luokista",
    "No apps found for your version" : "Sovelluksia ei löytynyt versiollesi",
    "Disable all" : "Poista kaikki käytöstä",
    "Enable all" : "Ota kaikki käyttöön",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n sovelluksella on päivitys saatavilla","%n sovelluksella on päivitys saatavilla"],
    "_Update_::_Update all_" : ["Päivitä","Päivitä kaikki"],
    "Marked for remote wipe" : "Merkitty etätyhjennettäväksi",
    "Device settings" : "Laiteasetukset",
    "Allow filesystem access" : "Salli pääsy tiedostojärjestelmään",
    "Rename" : "Nimeä uudelleen",
    "Revoke" : "Peru oikeus",
    "Wipe device" : "Tyhjennä laite",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome Android-laitteelle",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName}in iOS-sovellus",
    "{productName} Android app" : "{productName}in Android-sovellus",
    "{productName} Talk for iOS" : "{productName} Talk iOS:lle",
    "{productName} Talk for Android" : "{productName} Talk Androidille",
    "Sync client - {os}" : "Synkronointisovellus - {os}",
    "This session" : "Tämä istunto",
    "Device" : "Laite",
    "Last activity" : "Viimeksi käytetty",
    "Devices & sessions" : "Laitteet ja istunnot",
    "Web, desktop and mobile clients currently logged in to your account." : "Verkko-, työpöytä- ja mobiililaitteet, jotka ovat parhaillaan kirjautuneet tilillesi.",
    "Do you really want to wipe your data from this device?" : "Haluatko varmasit tyhjentää tiedot tältä laitteelta?",
    "Confirm wipe" : "Vahvista tyhjentäminen",
    "Error while creating device token" : "Virhe laitepolettia luotaessa",
    "Error while updating device token name" : "Virhe laitepoletin nimeä päivittäessä",
    "Error while deleting the token" : "Virhe polettia poistaessa",
    "Error while wiping the device with the token" : "Virhe tyhjennettäessä laitetta polettia käyttäen",
    "App name" : "Sovelluksen nimi",
    "Create new app password" : "Luo uusi sovellussalasana",
    "Use the credentials below to configure your app or device." : "Käytä oheista tunnusta ja salasanaa konfiguroidessasi sovelluksen tai laitteen.",
    "For security reasons this password will only be shown once." : "Turvallisuussyistä tämä salasana näytetään vain kerran.",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Done" : "Valmis",
    "Show QR code for mobile apps" : "Näytä QR-koodi mobiilisovelluksia varten",
    "Copied!" : "Kopioitu!",
    "Copy" : "Kopioi",
    "Could not copy app password. Please copy it manually." : "Sovellussalasanaa ei voitu kopioida. Kopioi se manuaalisesti.",
    "Cron (Recommended)" : "Cron (suositeltu)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Tämän suorittamiseksi tarvitset PHP:n POSIX-laajennuksen. Lue {linkstart}PHP:n dokumentaatio{linkend} saadaksesi lisätietoja.",
    "Profile" : "Profiili",
    "Enable or disable profile by default for new users." : "Käytä tai poista käytöstä profiili oletusarvoisesti uusille käyttäjille.",
    "Enable" : "Käytä",
    "Unable to update profile default setting" : "Profiilin oletusasetuksen päivittäminen ei onnistunut",
    "Server-side encryption" : "Palvelinpään salaus",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Palvelimelle ladatut tiedostot voidaan salata. Salaus aiheuttaa muun muassa palvelimen suorituskyvyn laskua, joten ota salaus käyttöön vain tarvittaessa.",
    "Enable server-side encryption" : "Käytä palvelinpään salausta",
    "Please read carefully before activating server-side encryption:" : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Kun salaus on otettu käyttöön, käyttöönoton jälkeen palvelimelle ladatut tiedostot salataan palvelimen ollessa lepotilassa. Salauksen ottaminen pois päältä myöhemmin on mahdollista vain, jos aktiivinen salausmoduuli tukee toiminta ja kaikki muut vaatimukset (kuten palautusavaimen asettaminen) täyttyvät.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Salaus sellaisenaan ei takaa järjestelmäsi turvallisuutta. Tutustu dokumentaation saadaksesi lisätietoja, miten salaussovellus toimii ja nähdäksesi tuettuja käyttötapauksia.",
    "Be aware that encryption always increases the file size." : "Ota huomioon, että salaus kasvattaa aina tiedostojen kokoa.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Säännöllisten varmuuskopioiden ottaminen on erittäin tärkeää. Jos olet ottanut salauksen käyttöön, huolehdi salausavainten varmuuskopioinnista.",
    "This is the final warning: Do you really want to enable encryption?" : "Tämä on viimeinen varoitus: haluatko varmasti ottaa salauksen käyttöön?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Salausmoduulia ei ole käytössä. Ota salausmoduuli käyttöön sovellusvalikosta.",
    "Select default encryption module:" : "Valitse oletuksena käytettävä salausmoduuli:",
    "Rename group" : "Nimeä ryhmä uudelleen",
    "Remove group" : "Poista ryhmä",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän {group}. Käyttäjiä EI poisteta!",
    "Please confirm the group removal " : "Vahvista ryhmän poistaminen",
    "Current password" : "Nykyinen salasana",
    "New password" : "Uusi salasana",
    "Change password" : "Vaihda salasana",
    "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
    "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
    "Cancel" : "Peru",
    "Your biography" : "Sinun elämäkertasi",
    "Your full name" : "Koko nimesi",
    "Email options" : "Sähköpostiasetukset",
    "Primary email for password reset and notifications" : "Ensisijainen sähköposti salasanan nollaamista ja ilmoituksia varten",
    "Remove primary email" : "Poista ensisijainen sähköpostiosoite",
    "Delete email" : "Poista sähköposti",
    "Unset as primary email" : "Poista ensisijaisesta sähköpostista",
    "This address is not confirmed" : "Tätä osoitetta ei ole vahvistettu",
    "Set as primary email" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
    "Your email address" : "Sähköpostiosoitteesi",
    "Additional email address {index}" : "Lisäsähköpostiosoite {index}",
    "Unable to delete primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu poistaa",
    "Unable to update primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu päivittää",
    "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
    "Additional emails" : "Muut sähköpostit",
    "Your headline" : "Otsikkosi",
    "Language" : "Kieli",
    "Help translate" : "Auta kääntämisessä",
    "Unable to update language" : "Kieltä ei voi päivittää",
    "No language set" : "Kieltä ei ole asetettu",
    "Your organisation" : "Organisaatiosi",
    "Your phone number" : "Puhelinnumerosi",
    "Edit your Profile visibility" : "Muokkaa profiilisi näkyvyyttä",
    "Enable Profile" : "Käytä profiilia",
    "Your role" : "Roolisi",
    "Your Twitter handle" : "Twitter-tunnuksesi",
    "Your website" : "Verkkosivustosi",
    "Add" : "Lisää",
    "You do not have permissions to see the details of this user" : "Käyttöoikeutesi eivät riitä tämän käyttäjän tietojen näkemiseen",
    "Add new password" : "Lisää uusi salasana",
    "Add new email address" : "Lisää uusi sähköpostiosoite",
    "Add user to group" : "Lisää käyttäjä ryhmään",
    "Set user as admin for" : "Aseta käyttäjä järjestelmänvalvojaksi kohteelle",
    "Select user quota" : "Valitse käyttäjäkiintiö",
    "Delete user" : "Poista käyttäjä",
    "Wipe all devices" : "Tyhjennä kaikki laitteet",
    "Disable user" : "Poista käyttäjä käytöstä",
    "Enable user" : "Ota käyttäjä käyttöön",
    "Resend welcome email" : "Lähetä uudelleen tervetuloviesti",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Laitteen kadotessa tai organisaatiosta poistuessa voidaan käyttäjälle {userid} Nextcloudiin yhdistetyistä laitteista pyyhkiä  tiedot. Toimii vain laitteiden ollessa yhteydessä Internetiin.",
    "Remote wipe of devices" : "Laitteiden etätyhjennys",
    "Wipe {userid}'s devices" : "Tyhjennä käyttäjän {userid} laitteet",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Poista täysin käyttäjän {userid} tili mukaan lukien henkilökohtaiset tiedostot, sovellusten tiedot jne.",
    "Account deletion" : "Tilin poistaminen",
    "Delete {userid}'s account" : "Poista käyttäjän {userid} tili",
    "Welcome mail sent!" : "Tervetuloviesti lähetetty!",
    "Edit User" : "Muokkaa käyttäjää",
    "{size} used" : "{size} käytetty",
    "New user" : "Uusi käyttäjä",
    "Will be autogenerated" : "Luodaan automaattisesti",
    "Display name" : "Näyttönimi",
    "Email" : "Sähköpostiosoite",
    "Default language" : "Oletuskieli",
    "Add a new user" : "Lisää uusi käyttäjä",
    "Group admin for" : "Ryhmäylläpitäjä ryhmille",
    "Quota" : "Kiintiö",
    "User backend" : "Käyttäjätaustaosa",
    "Storage location" : "Tallennustilan sijainti",
    "Last login" : "Viimeisin kirjautuminen",
    "No users in here" : "Täällä ei ole käyttäjiä",
    "Default quota" : "Oletuskiintiö",
    "Common languages" : "Yleiset kielet",
    "Other languages" : "Muut kielet",
    "Passwordless authentication requires a secure connection." : "Tunnistautuminen ilman salasanaa vaatii salatun yhteyden.",
    "Add WebAuthn device" : "Lisää WebAuthn-laite",
    "Please authorize your WebAuthn device." : "Valtuuta WebAuthn-laitteesi.",
    "Name your device" : "Nimeä laitteesi",
    "Adding your device …" : "Lisätään laitettasi…",
    "Server error while trying to add WebAuthn device" : "Palvelinvirhe kun yritettiin lisätä WebAuthn-laitetta",
    "Server error while trying to complete WebAuthn device registration" : "Palvelinvirhe kun yritettiin suorittaa WebAuthn-laitteen rekisteröintiä",
    "Unnamed device" : "Nimetön laite",
    "Passwordless Authentication" : "Tunnistautuminen ilman salasanaa",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Aseta tilillesi tunnistautuminen ilman salasanaa FIDO2-standardia seuraten.",
    "No devices configured." : "Laitteita ei ole määritetty.",
    "The following devices are configured for your account:" : "Seuraavat laitteet on määritetty tilillesi:",
    "Your browser does not support WebAuthn." : "Selaimesi ei tue WebAuthn-standardia.",
    "Your apps" : "Sovelluksesi",
    "Active apps" : "Aktiiviset sovellukset",
    "Disabled apps" : "Käytöstä poistetut sovellukset",
    "Updates" : "Päivitykset",
    "App bundles" : "Sovelluskokoelmat",
    "Featured apps" : "Esitellyt sovellukset",
    "{license}-licensed" : "{license}-lisensoitu",
    "Details" : "Yksityiskohdat",
    "Changelog" : "Muutosloki",
    "by {author}\n{license}" : "tekijä {author}\n{license}",
    "Enter group name" : "Kirjoita ryhmän nimi",
    "Add group" : "Lisää ryhmä",
    "Active users" : "Aktiiviset käyttäjät",
    "Admins" : "Ylläpitäjät",
    "Disabled users" : "Käytöstä poistetut käyttäjät",
    "Default quota:" : "Oletuskiintiö:",
    "Select default quota" : "Valitse oletuskiintiö",
    "Show Languages" : "Näytä kielet",
    "Show last login" : "Näytä viimeisin sisäänkirjautuminen",
    "Show user backend" : "Näytä käyttäjätaustaosa",
    "Show storage path" : "Näytä tallennustilan polku",
    "Send email to new user" : "Lähetä sähköpostia uudelle käyttäjälle",
    "Not saved" : "Ei tallennettu",
    "Sending…" : "Lähetetään…",
    "Email sent" : "Sähköposti lähetetty",
    "Location" : "Sijainti",
    "Profile picture" : "Profiilikuva",
    "About" : "Tietoja",
    "Full name" : "Koko nimi",
    "Headline" : "Otsikko",
    "Organisation" : "Organisaatio",
    "Phone number" : "Puhelinnumero",
    "Role" : "Rooli",
    "Twitter" : "Twitter",
    "Website" : "Verkkosivusto",
    "Profile visibility" : "Profiilin näkyvyys",
    "Show to everyone" : "Näytä kaikille",
    "Show to logged in users only" : "Näytä vain sisäänkirjautuneille käyttäjille",
    "Hide" : "Piilota",
    "Download and enable" : "Lataa ja ota käyttöön",
    "Enable untested app" : "Ota käyttöön testaamaton sovellus",
    "The app will be downloaded from the App Store" : "Sovellus ladataan sovelluskaupasta",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
    "Never" : "Ei koskaan",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Virhe: Sovellusta ei voida ottaa käyttöön, koska se aiheuttaa palvelimen epävakauden",
    "User already exists." : "Käyttäjä on jo olemassa.",
    "Administrator documentation" : "Ylläpidon dokumentaatio",
    "Documentation" : "Dokumentaatio",
    "Forum" : "Keskustelupalsta",
    "Login" : "Kirjaudu",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Avaa dokumentaatio",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On tärkeää määrittää sähköpostipalvelinasetukset, jotta voidaan lähettää muun muassa salasanan palautus- ja ilmoitussähköpostiviestejä.",
    "Send mode" : "Lähetystila",
    "Encryption" : "Salaus",
    "Sendmail mode" : "Sendmail-tila",
    "From address" : "Lähettäjän osoite",
    "Authentication method" : "Tunnistautumistapa",
    "Authentication required" : "Tunnistautuminen vaaditaan",
    "Server address" : "Palvelimen osoite",
    "Port" : "Portti",
    "Credentials" : "Tilitiedot",
    "SMTP Username" : "SMTP-käyttäjätunnus",
    "SMTP Password" : "SMTP-salasana",
    "Save" : "Tallenna",
    "Test and verify email settings" : "Testaa ja vahvista sähköpostiasetukset",
    "Send email" : "Lähetä sähköpostiviesti",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Turvallisuuden ja suorituskyvyn vuoksi on tärkeää, että palvelimen asetukset ovat määritetty oikein. Apuna on joitain automaattisia tarkistuksia. Lue lisätietoja linkitetystä dokumentaatiosta.",
    "All checks passed." : "Läpäistiin kaikki tarkistukset.",
    "There are some errors regarding your setup." : "Asetuksiin liittyen on muutamia virheitä.",
    "There are some warnings regarding your setup." : "Asetuksiin liittyen on muutamia varoituksia.",
    "Checking for system and security issues." : "Tarkistetaan mahdollisia järjestelmä- ja tietoturvaongelmia.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lue tarkkaan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">asennusohjeet ↗</a>, ja tarkista virheet sekä varoitukset <a href=\"%2$s\">lokista</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Tarkista Nextcloudisi turvallisuus käyttäen <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">tietoturvakartoitustamme ↗</a>.",
    "Version" : "Versio",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ylläpitäjänä voit hienosäätää jakamista. Katso dokumentaatiosta lisätietoa.",
    "Allow apps to use the Share API" : "Salli sovellusten käyttää jakamisen ohjelmointirajapintaa",
    "Set default expiration date for shares" : "Aseta oletusarvoinen vanhenemispäivä jaoille",
    "Expire after" : "Lopeta jako, kun on kulunut",
    "day(s)" : "päivä(ä)",
    "Enforce expiration date" : "Pakota vanhenemispäivä",
    "Set default expiration date for shares to other servers" : "Aseta oletuspäivä muille palvelimille tehtyjen jakojen lopettamiselle",
    "Allow users to share via link and emails" : "Salli käyttäjien jakaa linkkien ja sähköpostin kautta",
    "Allow public uploads" : "Salli julkiset lähetykset",
    "Always ask for a password" : "Kysy aina salasanaa",
    "Enforce password protection" : "Pakota salasanasuojaus",
    "Set default expiration date" : "Aseta lopettamispäivän oletus",
    "Allow resharing" : "Salli uudelleenjakaminen",
    "Allow sharing with groups" : "Salli jakaminen ryhmien kanssa",
    "Restrict users to only share with users in their groups" : "Salli käyttäjien jakaa vain omassa ryhmässä olevien henkilöiden kesken",
    "Exclude groups from sharing" : "Kiellä ryhmiä jakamasta",
    "These groups will still be able to receive shares, but not to initiate them." : "Nämä ryhmät kykenevät vastaanottamaan jakoja, mutta eivät kuitenkaan itse pysty luoda jakoja.",
    "Allow username autocompletion in share dialog" : "Ota käyttöön käyttäjänimen automaattitäyttö jakolomakkeessa",
    "Allow username autocompletion to users within the same groups" : "Ota käyttöön käyttäjänimen automaattitäyttö saman ryhmän käyttäjille",
    "This text will be shown on the public link upload page when the file list is hidden." : "Tämä teksti näytetään julkisen linkin lähetyssivulla, kun tiedostolista on piilotettu.",
    "Default share permissions" : "Oletusjako-oikeudet",
    "Reasons to use Nextcloud in your organization" : "Nextcloudin käytön edut organisaatiossasi",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Kehityksestä on vastannut {communityopen}Nextcloud-yhteisö{linkclose}, {githubopen}lähdekoodi{linkclose} on {licenseopen}AGPL-lisensoitu{linkclose}.",
    "Like our Facebook page" : "Tykkää Facebook-sivustamme",
    "Follow us on Twitter" : "Seuraa meitä Twitterissä",
    "Follow us on Mastodon" : "Seuraa meitä Mastodonissa",
    "Check out our blog" : "Lue blogia",
    "Subscribe to our newsletter" : "Tilaa uutiskirje",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
    "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
    "You are using <strong>%s</strong>" : "Käytössäsi on <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Käytössäsi on <strong>%1$s</strong> / <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Locale" : "Aluekohtainen asetus",
    "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
    "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
    "Migration started …" : "Migraatio käynnistyi…",
    "Select a profile picture" : "Valitse profiilikuva",
    "Couldn't remove app." : "Sovelluksen poistaminen epäonnistui.",
    "Couldn't update app." : "Sovelluksen päivitys epäonnistui.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Taustaosa ei tue salasanan vaihtamista, mutta käyttäjän salausavain päivitettiin.",
    "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
    "Set as primary mail" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
    "Change privacy level of email" : "Muuta sähköpostin yksityisyystasoa",
    "All languages" : "Kaikki kielet",
    "Everyone" : "Kaikki",
    "An error occured during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
    "Test email settings" : "Testaa sähköpostiasetukset",
    "Please read carefully before activating server-side encryption: " : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
    "Enable encryption" : "Käytä salausta",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen. Ota \"Default encryption module\" käyttöön ja suorita komento 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen.",
    "Start migration" : "Käynnistä migraatio",
    "Last job execution ran %s. Something seems wrong." : "Viimeisin cron-työn suoritus %s. Jokin vaikuttaa menneen pieleen.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Jotkin tehtävät on suoritettu viimeksi %s jälkeen. Harkitse suoritustiheyden nopeuttamista.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Joidenkin tehtävien suoritukset ovat onnistuneet viimeksi %s. Harkitse vaihtoa järjestelmän cron-palveluun.",
    "Last job ran %s." : "Viimeisin työ suoritettu %s.",
    "Background job didn’t run yet!" : "Taustatyötä ei suoritettu vielä!",
    "Pick background job setting" : "Valitse taustatyöasetus",
    "Recommended" : "Suositeltu",
    "The cron.php needs to be executed by the system user \"%s\"." : "Tiedosto cron.php tulee suorittaa järjestelmän käyttäjänä \"%s\".",
    "days" : "päivän jälkeen",
    "Change privacy level of profile picture" : "Muuta profiilikuvan yksityisyystasoa",
    "Upload new" : "Lähetä uusi",
    "Select from Files" : "Valitse tiedostosovelluksesta",
    "Remove image" : "Poista kuva",
    "Choose as profile picture" : "Valitse profiilikuvaksi",
    "Change privacy level of full name" : "Muuta koko nimen yksityisyystasoa",
    "No display name set" : "Näyttönimeä ei ole asetettu",
    "Change privacy level of phone number" : "Muuta puhelinnumeron yksityisyystasoa",
    "Address" : "Osoite",
    "Change privacy level of address" : "Muuta osoitteen yksityisyystasoa",
    "Your postal address" : "Postiosoitteesi",
    "Change privacy level of website" : "Muuta verkkosivuston yksityisyystasoa",
    "It can take up to 24 hours before the account is displayed as verified." : "Saattaa kestää jopa 24 tuntia, ennen kuin tili näytetään vahvistettuna.",
    "Link https://…" : "Linkki https://…",
    "Change privacy level of Twitter profile" : "Muuta Twitter-tunnuksen yksityisyystasoa",
    "Twitter handle @…" : "Twitter-tunnus @…",
    "Admin privileges" : "Ylläpitäjän oikeudet",
    "Unable to update full name" : "Koko nimeä ei voi päivittää",
    "No full name set" : "Koko nimeä ei ole asetettu",
    "Unable to update organisation" : "Organisaatiota ei voi päivittää",
    "Unable to update role" : "Roolin päivittäminen ei onnistu",
    "Avatar" : "Profiilikuva"
},
"nplurals=2; plural=(n != 1);");
